==> nats.c_3.2.0.orig.tar.gz: nats.c-3.2.0/doc/html/group__kv_group.js <==
var group__kv_group =
[
    [ "KeyValue store management", "group__kv_group_mgt.html", "group__kv_group_mgt" ],
    [ "KeyValue store entries", "group__kv_entry.html", "group__kv_entry" ],
    [ "KeyValue store watcher", "group__kv_watcher.html", "group__kv_watcher" ],
    [ "KeyValue store status", "group__kv_status.html", "group__kv_status" ],
    [ "kvStore_Get", "group__kv_group.html#ga2db86f80d6bfce1bdbedf1b9da22913c", null ],
    [ "kvStore_Put", "group__kv_group.html#ga1fdf7a1d3acf96e475184790589a401e", null ],
    [ "kvStore_PutString", "group__kv_group.html#ga84ebd66a95ce857765d4a16ec35daba9", null ],
    [ "kvStore_Create", "group__kv_group.html#ga5289f7cd3999cfb46fb1fcb83178aec6", null ],
    [ "kvStore_CreateString", "group__kv_group.html#ga5726ad2e6205d2f6749be013138218ca", null ],
    [ "kvStore_Update", "group__kv_group.html#gae0c593bb2ef94ae60e775617c9423038", null ],
    [ "kvStore_UpdateString", "group__kv_group.html#ga13ed70f15cd1485cd15f96bcc4b7ad1c", null ],
    [ "kvStore_Delete", "group__kv_group.html#ga68101d46739ca894fd7c56c8661c08d8", null ],
    [ "kvStore_Purge", "group__kv_group.html#ga642970938345ee6b98ce3d9230034b36", null ],
    [ "kvWatchOptions_Init", "group__kv_group.html#ga762fd5de8cde683e46a6736a51e575f5", null ],
    [ "kvStore_PurgeDeletes", "group__kv_group.html#ga8870506415465a7272b4fe6902c0aec3", null ],
    [ "kvStore_Watch", "group__kv_group.html#ga30feca870f580c7b9d2ad07a740505b2", null ],
    [ "kvStore_WatchAll", "group__kv_group.html#gaf011f1dd6813391c65664e982747602e", null ],
    [ "kvStore_Keys", "group__kv_group.html#ga6030fc2a672ae868f7603587245b9d5a", null ],
    [ "kvKeysList_Destroy", "group__kv_group.html#ga02ccd58bc5062f6ce6f94bf05e3dfe45", null ],
    [ "kvStore_History", "group__kv_group.html#ga5aa57345313cee85b020e50c22023fb5", null ],
    [ "kvEntryList_Destroy", "group__kv_group.html#gae783352ab81e22aa3173057d117518e6", null ],
    [ "kvStore_Bucket", "group__kv_group.html#gad28fdf9aae16bba308cda799fca13281", null ],
    [ "kvStore_Status", "group__kv_group.html#gadf75e99cc28bc9c2d6eac7c9f7398c27", null ]
];

==> nats.c_3.4.1.orig.tar.gz: nats.c-3.4.1/doc/html/group__kv_group.js <==
var group__kv_group =
[
    [ "KeyValue store management", "group__kv_group_mgt.html", "group__kv_group_mgt" ],
    [ "KeyValue store entries", "group__kv_entry.html", "group__kv_entry" ],
    [ "KeyValue store watcher", "group__kv_watcher.html", "group__kv_watcher" ],
    [ "KeyValue store status", "group__kv_status.html", "group__kv_status" ],
    [ "kvStore_Get", "group__kv_group.html#ga2db86f80d6bfce1bdbedf1b9da22913c", null ],
    [ "kvStore_GetRevision", "group__kv_group.html#ga9bf43431bb8264a3ea1f0df401afbe1a", null ],
    [ "kvStore_Put", "group__kv_group.html#ga1fdf7a1d3acf96e475184790589a401e", null ],
    [ "kvStore_PutString", "group__kv_group.html#ga84ebd66a95ce857765d4a16ec35daba9", null ],
    [ "kvStore_Create", "group__kv_group.html#ga5289f7cd3999cfb46fb1fcb83178aec6", null ],
    [ "kvStore_CreateString", "group__kv_group.html#ga5726ad2e6205d2f6749be013138218ca", null ],
    [ "kvStore_Update", "group__kv_group.html#gae0c593bb2ef94ae60e775617c9423038", null ],
    [ "kvStore_UpdateString", "group__kv_group.html#ga13ed70f15cd1485cd15f96bcc4b7ad1c", null ],
    [ "kvStore_Delete", "group__kv_group.html#ga68101d46739ca894fd7c56c8661c08d8", null ],
    [ "kvStore_Purge", "group__kv_group.html#ga3d5fa3d895d0d3041440105b244e9ca9", null ],
    [ "kvWatchOptions_Init", "group__kv_group.html#ga762fd5de8cde683e46a6736a51e575f5", null ],
    [ "kvPurgeOptions_Init", "group__kv_group.html#ga243113fd7df34ce104850ab888f04021", null ],
    [ "kvStore_PurgeDeletes", "group__kv_group.html#ga34ab74b229ff88e64301ea53a274da69", null ],
    [ "kvStore_Watch", "group__kv_group.html#ga30feca870f580c7b9d2ad07a740505b2", null ],
    [ "kvStore_WatchAll", "group__kv_group.html#gaf011f1dd6813391c65664e982747602e", null ],
    [ "kvStore_Keys", "group__kv_group.html#ga6030fc2a672ae868f7603587245b9d5a", null ],
    [ "kvKeysList_Destroy", "group__kv_group.html#ga02ccd58bc5062f6ce6f94bf05e3dfe45", null ],
    [ "kvStore_History", "group__kv_group.html#ga5aa57345313cee85b020e50c22023fb5", null ],
    [ "kvEntryList_Destroy", "group__kv_group.html#gae783352ab81e22aa3173057d117518e6", null ],
    [ "kvStore_Bucket", "group__kv_group.html#gad28fdf9aae16bba308cda799fca13281", null ],
    [ "kvStore_Status", "group__kv_group.html#gadf75e99cc28bc9c2d6eac7c9f7398c27", null ]
];
